# Changelog

## [v0.6.0](https://github.com/sansyrox/robyn/tree/HEAD)

[Full Changelog](https://github.com/sansyrox/robyn/compare/v0.5.3...v0.6.0)

**Closed issues:**

- Add body support for PUT, POST and PATCH [\#53](https://github.com/sansyrox/robyn/issues/53)
- Away with limited internet access till 1st August [\#51](https://github.com/sansyrox/robyn/issues/51)
- Add doc stings [\#42](https://github.com/sansyrox/robyn/issues/42)
- OSX builds are failing [\#41](https://github.com/sansyrox/robyn/issues/41)
- Add a dev server implementation [\#37](https://github.com/sansyrox/robyn/issues/37)
- Mini Roadmap | A list of issues that would require fixing [\#19](https://github.com/sansyrox/robyn/issues/19)
- Add support for Object/JSON Return Type! [\#9](https://github.com/sansyrox/robyn/issues/9)

**Merged pull requests:**

- Update to pyo3 v0.14 [\#65](https://github.com/sansyrox/robyn/pull/65) ([sansyrox](https://github.com/sansyrox))
- Add the static directory serving [\#64](https://github.com/sansyrox/robyn/pull/64) ([sansyrox](https://github.com/sansyrox))
- Create a request object [\#61](https://github.com/sansyrox/robyn/pull/61) ([sansyrox](https://github.com/sansyrox))
- Add the ability to add body in PUT, PATCH and DELETE [\#60](https://github.com/sansyrox/robyn/pull/60) ([sansyrox](https://github.com/sansyrox))
- Implement a working dev server [\#40](https://github.com/sansyrox/robyn/pull/40) ([sansyrox](https://github.com/sansyrox))
- Use Actix as base [\#35](https://github.com/sansyrox/robyn/pull/35) ([JackThomson2](https://github.com/JackThomson2))

## [v0.5.3](https://github.com/sansyrox/robyn/tree/v0.5.3) (2021-07-12)

[Full Changelog](https://github.com/sansyrox/robyn/compare/v0.5.2...v0.5.3)

**Merged pull requests:**

- Improve the HTML file serving [\#46](https://github.com/sansyrox/robyn/pull/46) ([sansyrox](https://github.com/sansyrox))
- Add the basics to add serving of static files [\#36](https://github.com/sansyrox/robyn/pull/36) ([sansyrox](https://github.com/sansyrox))

## [v0.5.2](https://github.com/sansyrox/robyn/tree/v0.5.2) (2021-07-11)

[Full Changelog](https://github.com/sansyrox/robyn/compare/v0.5.1...v0.5.2)

## [v0.5.1](https://github.com/sansyrox/robyn/tree/v0.5.1) (2021-07-10)

[Full Changelog](https://github.com/sansyrox/robyn/compare/v0.5.0...v0.5.1)

**Closed issues:**

- Make html file serving more robust [\#45](https://github.com/sansyrox/robyn/issues/45)
- Try to serve individual static files using vanilla rust [\#43](https://github.com/sansyrox/robyn/issues/43)
- Error on import  [\#16](https://github.com/sansyrox/robyn/issues/16)
- Add multiple process sharing [\#2](https://github.com/sansyrox/robyn/issues/2)

## [v0.5.0](https://github.com/sansyrox/robyn/tree/v0.5.0) (2021-07-01)

[Full Changelog](https://github.com/sansyrox/robyn/compare/v0.4.1...v0.5.0)

**Closed issues:**

- QPS drops drastically after processing many requests [\#31](https://github.com/sansyrox/robyn/issues/31)
- Improve the way you parse TCP streams [\#30](https://github.com/sansyrox/robyn/issues/30)
- Re-introduce thread pool for the sync functions \(maybe\) [\#22](https://github.com/sansyrox/robyn/issues/22)
- Add async listener object in rust stream! [\#11](https://github.com/sansyrox/robyn/issues/11)

**Merged pull requests:**

- Make the server http compliant [\#33](https://github.com/sansyrox/robyn/pull/33) ([sansyrox](https://github.com/sansyrox))

## [v0.4.1](https://github.com/sansyrox/robyn/tree/v0.4.1) (2021-06-26)

[Full Changelog](https://github.com/sansyrox/robyn/compare/0.4.0...v0.4.1)

**Closed issues:**

- Add PyPi Metadata [\#5](https://github.com/sansyrox/robyn/issues/5)

**Merged pull requests:**

- Build and publish wheels on GitHub Actions [\#26](https://github.com/sansyrox/robyn/pull/26) ([messense](https://github.com/messense))
- Code cleanup using PyFunction type [\#25](https://github.com/sansyrox/robyn/pull/25) ([sansyrox](https://github.com/sansyrox))
- Add non blocking sync functions [\#23](https://github.com/sansyrox/robyn/pull/23) ([sansyrox](https://github.com/sansyrox))
- Add support for sync functions [\#20](https://github.com/sansyrox/robyn/pull/20) ([sansyrox](https://github.com/sansyrox))

## [0.4.0](https://github.com/sansyrox/robyn/tree/0.4.0) (2021-06-22)

[Full Changelog](https://github.com/sansyrox/robyn/compare/v0.3.0...0.4.0)

**Closed issues:**

- Add support for Sync functions as well! [\#7](https://github.com/sansyrox/robyn/issues/7)

## [v0.3.0](https://github.com/sansyrox/robyn/tree/v0.3.0) (2021-06-21)

[Full Changelog](https://github.com/sansyrox/robyn/compare/v0.2.3...v0.3.0)

**Closed issues:**

- Architecture link in readme redirects to raw content [\#18](https://github.com/sansyrox/robyn/issues/18)
- Link pointing to the wrong destination [\#6](https://github.com/sansyrox/robyn/issues/6)

**Merged pull requests:**

- Pure tokio [\#17](https://github.com/sansyrox/robyn/pull/17) ([JackThomson2](https://github.com/JackThomson2))
- Remove Mutex lock on Threadpool and routes [\#15](https://github.com/sansyrox/robyn/pull/15) ([JackThomson2](https://github.com/JackThomson2))

## [v0.2.3](https://github.com/sansyrox/robyn/tree/v0.2.3) (2021-06-18)

[Full Changelog](https://github.com/sansyrox/robyn/compare/c14f52e6faa79917e89de4220590da7bf28f6a65...v0.2.3)

**Closed issues:**

- Improve async runtime [\#3](https://github.com/sansyrox/robyn/issues/3)



\* *This Changelog was automatically generated by [github_changelog_generator](https://github.com/github-changelog-generator/github-changelog-generator)*
